@@ -19,8 +19,8 @@ import pipes
 import platform
 import sys
 import tempfile
+from unittest import mock
 
-import mock
 import testtools
 
 from oslo_privsep import daemon
@@ -127,6 +127,16 @@ class PrivContextTest(testctx.TestContextTestCase):
         self.assertEqual(testctx.context.helper_command('/sock')[:3],
                          ['sudo', 'rootwrap', 'privsep-helper'])
 
+    def test_start_acquires_lock(self):
+        context = priv_context.PrivContext('test', capabilities=[])
+        context.channel = "something not None"
+        context.start_lock = mock.Mock()
+        context.start_lock.__enter__ = mock.Mock()
+        context.start_lock.__exit__ = mock.Mock()
+        self.assertFalse(context.start_lock.__enter__.called)
+        context.start()
+        self.assertTrue(context.start_lock.__enter__.called)
+
 
 @testtools.skipIf(platform.system() != 'Linux',
                   'works only on Linux platform.')
@@ -186,7 +196,7 @@ class SerializationTest(testctx.TestContextTestCase):
         self.assertEqual(43, add1(42))
 
     def test_raises_standard(self):
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             RuntimeError, "I can't let you do that Dave", fail)
 
     def test_raises_custom(self):
